Reqord.JSON.Poison (reqord v0.4.0)

JSON adapter for the Poison library.

This adapter allows using Poison instead of Jason for JSON encoding/decoding.

Usage

Add Poison to your dependencies and configure Reqord to use it:

# mix.exs
def deps do
  [
    {:poison, "~> 5.0"},
    {:reqord, "~> 0.1.0"}
  ]
end

# config/config.exs
config :reqord, :json_library, Reqord.JSON.Poison

Features

  • Pure Elixir implementation
  • Good performance for most use cases
  • Wide ecosystem compatibility