Reqord.Replay (reqord v0.4.0)
View SourceHandles replaying HTTP requests from cassettes.
Summary
Functions
Loads the response body based on the encoding type and storage method.
Replays a response from a cassette entry with support for different body encodings.
Functions
@spec load_response_body(Reqord.CassetteEntry.Response.t()) :: {:ok, binary()} | {:error, String.t()}
Loads the response body based on the encoding type and storage method.
@spec replay_response(Plug.Conn.t(), Reqord.CassetteEntry.t()) :: Plug.Conn.t()
Replays a response from a cassette entry with support for different body encodings.